@@ -5,7 +5,7 @@ import traceback
 import io
 from multiprocessing import Process, Pipe, Queue
 from typing import BinaryIO
-from ultraplex.qualtrim2 import quality_trim_index
+from .qualtrim2 import quality_trim_index
 from ultraplex.modifiers import AdapterCutter, ModificationInfo
 from ultraplex.adapters import BackAdapter
 import gzip
